@@ -3,14 +3,16 @@ import json
 from contextlib import contextmanager
 
 from airflow.exceptions import AirflowException, AirflowSkipException
-from dagster import check, seven
+from dagster_airflow.vendor.docker_operator import DockerOperator
+from docker import APIClient, from_env
+
+import dagster._check as check
+import dagster.seven as seven
 from dagster.core.execution.api import create_execution_plan
 from dagster.core.execution.plan.plan import should_skip_step
 from dagster.core.instance import AIRFLOW_EXECUTION_DATE_STR, DagsterInstance
 from dagster.grpc.types import ExecuteStepArgs
 from dagster.serdes import deserialize_json_to_dagster_namedtuple, serialize_dagster_namedtuple
-from dagster_airflow.vendor.docker_operator import DockerOperator
-from docker import APIClient, from_env
 
 from .util import check_events_for_failures, check_events_for_skips, get_aws_environment
 
@@ -61,7 +63,7 @@ class DagsterDockerOperator(DockerOperator):
         if not self.docker_conn_id_set:
             try:
                 from_env().version()
-            except Exception:  # pylint: disable=broad-except
+            except Exception:
                 pass
             else:
                 kwargs["docker_conn_id"] = True
@@ -255,7 +257,7 @@ class DagsterDockerOperator(DockerOperator):
             try:
                 events = [deserialize_json_to_dagster_namedtuple(line) for line in res if line]
 
-            except Exception:  # pylint: disable=broad-except
+            except Exception:
                 raise AirflowException(
                     "Could not parse response {response}".format(response=repr(res))
                 )
